==> acornlib-1.21.5-r19-sources.jar: net/acoyt/acornlib/impl/mixin/client/PlayerEntityRendererMixin.java <==
package net.acoyt.acornlib.impl.mixin.client;

import net.acoyt.acornlib.impl.index.AcornComponents;
import net.minecraft.class_10055;
import net.minecraft.class_1007;
import net.minecraft.class_1306;
import net.minecraft.class_1799;
import net.minecraft.class_5617;
import net.minecraft.class_572.class_573;
import net.minecraft.class_591;
import net.minecraft.class_742;
import net.minecraft.class_922;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1007.class)
public abstract class PlayerEntityRendererMixin extends class_922<class_742, class_10055, class_591> {
    public PlayerEntityRendererMixin(class_5617.class_5618 ctx, class_591 model, float shadowRadius) {
        super(ctx, model, shadowRadius);
    }

    @Inject(
            method = "getArmPose(Lnet/minecraft/client/network/AbstractClientPlayerEntity;Lnet/minecraft/util/Arm;)Lnet/minecraft/client/render/entity/model/BipedEntityModel$ArmPose;",
            at = @At("HEAD"),
            cancellable = true
    )
    private static void skylight$twoHandedPoses(class_742 player, class_1306 arm, CallbackInfoReturnable<class_573> cir) {
        class_1799 stack = player.method_61420(arm);
        if (stack.method_57826(AcornComponents.TWO_HANDED)) {
            cir.setReturnValue(class_573.field_3405);
        }

        if (stack.method_57826(AcornComponents.FOLLOWS_CAM)) {
            cir.setReturnValue(class_573.field_3408);
        }
    }
}

==> acornlib-1.21.8-r5-sources.jar: net/acoyt/acornlib/impl/mixin/client/PlayerEntityRendererMixin.java <==
package net.acoyt.acornlib.impl.mixin.client;

import net.acoyt.acornlib.impl.init.AcornComponents;
import net.minecraft.class_10055;
import net.minecraft.class_1007;
import net.minecraft.class_1306;
import net.minecraft.class_1799;
import net.minecraft.class_5617;
import net.minecraft.class_572.class_573;
import net.minecraft.class_591;
import net.minecraft.class_742;
import net.minecraft.class_922;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1007.class)
public abstract class PlayerEntityRendererMixin extends class_922<class_742, class_10055, class_591> {
    public PlayerEntityRendererMixin(class_5617.class_5618 ctx, class_591 model, float shadowRadius) {
        super(ctx, model, shadowRadius);
    }

    @Inject(
            method = "getArmPose(Lnet/minecraft/client/network/AbstractClientPlayerEntity;Lnet/minecraft/util/Arm;)Lnet/minecraft/client/render/entity/model/BipedEntityModel$ArmPose;",
            at = @At("HEAD"),
            cancellable = true
    )
    private static void skylight$twoHandedPoses(class_742 player, class_1306 arm, CallbackInfoReturnable<class_573> cir) {
        class_1799 stack = player.method_61420(arm);
        if (stack.method_57826(AcornComponents.TWO_HANDED)) {
            cir.setReturnValue(class_573.field_3405);
        }

        if (stack.method_57826(AcornComponents.FOLLOWS_CAM)) {
            cir.setReturnValue(class_573.field_3408);
        }
    }
}
